<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:import href="Utils/Misc.xsl"/>
    <xsl:import href="Detailed%20Report.xsl"/>
    <xsl:param name="contextName"/>
    <xsl:param name="title" select="concat(tokenize($contextName,'/')[last()], ' Performance Test Report')"/>
    
    <xsl:template match="/">
        <html>
            <head>
                <title>
                    <xsl:value-of select="$title"/>
                </title>
                <link rel="stylesheet" type="text/css" href="resourcestyle.css" />
            </head>
            <body>
                <a name="top"/>
                <xsl:call-template
                    name="perfhead">
                </xsl:call-template>
                <xsl:call-template
                    name="perftable">
                </xsl:call-template>
            </body>
        </html>
    </xsl:template>
    
    <xsl:template name="perfhead">
        <div
            style="margin: 0px 0px 0px 0px;">
            <img
                src="logo.jpg"
                alt="Green Hat Consulting"
                style="float: left;"
                border="0"/>
            <h1>
                <xsl:value-of select="$title"/>
            </h1>
            <table
                class="faux">
                <tr>
                    <th>Performance Test:</th>
                    <td>
                        <xsl:value-of select="$contextName"/>
                    </td>
                </tr>
                <tr>
                    <th>Environment:</th>
                    <td>
                        <xsl:value-of select="PerfTest/@environment"/>
                    </td>
                </tr>
                <tr>
                    <th>Start Time:</th>
                    <td>
                        <xsl:value-of select="PerfTest/@startTime"/>
                    </td>
                </tr>
                <tr>
                    <th>End Time:</th>
                    <td>
                        <xsl:value-of select="PerfTest/@endTime"/>
                    </td>
                </tr>
                <tr>
                    <xsl:call-template
                        name="X_writeNameValuePair">
                        <xsl:with-param name="name" select="'Run Time (ms)'"/>
                        <xsl:with-param
                            name="value">
                            <xsl:choose>
                                <xsl:when test="PerfTest/@duration">
                                    <xsl:value-of select="PerfTest/@duration"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="'Running...'"/>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:with-param>
                    </xsl:call-template>
                </tr>
            </table>
        </div>
    </xsl:template>
    
    <xsl:template
        name="perftable">
        <h2>Summary</h2>
        <table>
            <tr>
                <th>Iterations</th>
                <th>Iteration Avg Time(ms)</th>
                <th>Iteration Max Time(ms)</th>
                <th>Transactions</th>
                <th>Trans Avg Time(ms)</th>
                <th>Trans Max Time(ms)</th>
            </tr>
            <tr>
                <td>
                    <xsl:value-of
                        select="PerfTest/@iterations"/>
                </td>
                <td>
                    <xsl:value-of
                        select="PerfTest/@avgIterDur"/>
                </td>
                <td>
                    <xsl:value-of
                        select="PerfTest/@maxIterDur"/>
                </td>
                <td>
                    <xsl:value-of
                        select="PerfTest/@transactions"/>
                </td>
                <td>
                    <xsl:value-of
                        select="PerfTest/@avgTransDur"/>
                </td>
                <td>
                    <xsl:value-of
                        select="PerfTest/@maxTransDur"/>
                </td>
            </tr>
        </table>
    </xsl:template>
</xsl:stylesheet>
