<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	<xsl:template match="/">
		<xsl:variable name="y" select="//coverage[1]"/>
		<html>
			<head>
				<title>TIBCO BusinessWorks Coverage Report</title>
				<link rel="stylesheet" type="text/css" href="resourcestyle.css"/>
				<link rel="stylesheet" type="text/css" href="vanilla.css"/>
			</head>
			<body>
				<h1>TIBCO BusinessWorks Coverage Report</h1>
				<h2>Summary</h2>
				<div>
					<table>
						<thead>
							<tr>
								<th class="left">Process</th>
								<th>Activities Run</th>
								<th>Activities Missed</th>
								<th>Coverage</th>
							</tr>
						</thead>
						<tbody>
							<xsl:for-each select="$y/processes/process">
								<tr>
									<td class="left">
										<xsl:value-of select="@name"/>
									</td>
									<td>
										<xsl:value-of select="count(activities/activity[@frq > 0])"/>
									</td>
									<td>
										<xsl:value-of select="count(activities/activity[not(@frq > 0)])"/>
									</td>
									<td>
										<xsl:value-of select="concat(round(100 * count(activities/activity[@frq > 0]) div count(activities/activity)),'%')"/>
									</td>
								</tr>
							</xsl:for-each>
						</tbody>
						<tfoot>
							<tr>
								<th class="left">Total</th>
								<th>
									<xsl:value-of select="count($y/processes/process/activities/activity[@frq > 0])"/>
								</th>
								<th>
									<xsl:value-of select="count($y/processes/process/activities/activity[not(@frq > 0)])"/>
								</th>
								<th>
									<xsl:value-of select="concat(round(100 * avg( for $x in $y/processes/process return if ($x/activities/activity) then count($x/activities/activity[@frq > 0]) div count($x/activities/activity) else 0)),'%')"/>
								</th>
							</tr>
						</tfoot>
					</table>
				</div>
				<xsl:if test="$y/processes/process[activities/activity[@frq > 0]]">
					<h2>Detail</h2>
					<xsl:for-each select="$y/processes/process[activities/activity[@frq > 0]]">
						<h3>
							<xsl:value-of select="concat(@name,' (',round(100 * count(activities/activity[@frq > 0]) div count(activities/activity)),'% coverage)')"/>
						</h3>
						<div>
							<xsl:if test="activities/activity[not(@frq > 0)]">
								<h4>Activities missed</h4>
								<ul>
									<xsl:for-each select="activities/activity[not(@frq > 0)]">
										<li>
											<xsl:value-of select="@name"/>
										</li>
									</xsl:for-each>
								</ul>
							</xsl:if>
							<xsl:if test="activities/activity[@frq > 0]">
								<h4>Activities covered</h4>
								<table>
									<thead>
										<tr>
											<th class="left">Activity</th>
											<th>Number of Times Called</th>
											<th>Minimum Time (ms)</th>
											<th>Maximum Time (ms)</th>
											<th>Average Time (ms)</th>
											<th>Total Time (ms)</th>
										</tr>						
									</thead>
									<tbody>
										<xsl:for-each select="activities/activity[@frq > 0]">
											<tr>
												<td class="left">
													<xsl:value-of select="@name"/>
												</td>
												<td>
													<xsl:value-of select="@frq"/>
												</td>
												<td>
													<xsl:value-of select="@min"/>
												</td>
												<td>
													<xsl:value-of select="@max"/>
												</td>
												<td>
													<xsl:value-of select="@avg"/>
												</td>
												<td>
													<xsl:value-of select="@sum"/>
												</td>
											</tr>
										</xsl:for-each>
									</tbody>
								</table>
							</xsl:if>
						</div>
					</xsl:for-each>
				</xsl:if>
			</body>
		</html>
	</xsl:template>
</xsl:stylesheet>