<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:import href="Utils/Misc.xsl"/>
	<xsl:import href="Detailed%20Report.xsl"/>
	<xsl:param name="contextName"/>
	<xsl:param name="title" select="concat(tokenize($contextName,'/')[last()], ' Summary Test Suite Report')"/>
	
	<xsl:template match="/">
		<html>
			<head>
				<title>
					<xsl:value-of select="$title"/>
				</title>
				<link rel="stylesheet" type="text/css" href="resourcestyle.css" />
			</head>
			<body>
				<a name="top"/>
				<xsl:variable
					name="results"
					select="document(TestSuite/task/@logLocation)/Test/summary"/>
				<xsl:call-template
					name="head">
					<xsl:with-param
						name="results"
						select="$results"/>
				</xsl:call-template>
				<xsl:call-template
					name="summary">
					<xsl:with-param
						name="results"
						select="$results"/>
				</xsl:call-template>
				<xsl:call-template
					name="table">
					<xsl:with-param
						name="results"
						select="$results"/>
				</xsl:call-template>
			</body>
		</html>
	</xsl:template>
	
	<xsl:template name="head">
		<xsl:param name="results"/>
		<div
			style="margin: 0px 0px 10px 0px;">
			<img
				src="logo.jpg"
				alt="Green Hat Consulting"
				style="float: left;"
				border="0"/>
			<h1>
				<xsl:value-of select="$title"/>
			</h1>
			<table
				class="faux">
				<tr>
					<th>Suite:</th>
					<td>
						<xsl:value-of select="$contextName"/>
					</td>
				</tr>
				<tr>
					<th>Scenario:</th>
					<td>
						<xsl:value-of select="TestSuite/@resource"/>
					</td>
				</tr>
				<tr>
					<xsl:choose>
						<xsl:when test="count(distinct-values( $results/../environment/@name )) &gt; 1">
							<th>Environments:</th>
						</xsl:when>
						<xsl:otherwise>
							<th>Environment:</th>
						</xsl:otherwise>
					</xsl:choose>
					<td>
						<xsl:value-of select="string-join(distinct-values( $results/../environment/@name ), ', ')"/>
					</td>
				</tr>
				<tr>
					<th>Overall Status:</th>
					<td>
						<xsl:variable name="status">
							<xsl:call-template name="status">
								<xsl:with-param name="results" select="$results"/>
							</xsl:call-template>
						</xsl:variable>
						<xsl:attribute name="class">
							<xsl:value-of select="lower-case($status)"/>
						</xsl:attribute>
						<xsl:value-of select="$status"/>
					</td>
				</tr>
				<tr>
					<xsl:call-template
						name="X_writeNameValuePair">
						<xsl:with-param name="name" select="'Run Time (ms)'"/>
						<xsl:with-param
							name="value">
							<xsl:choose>
								<xsl:when test="TestSuite/@duration">
									<xsl:value-of select="TestSuite/@duration"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="'Running...'"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:with-param>
					</xsl:call-template>
				</tr>
			</table>
		</div>
	</xsl:template>
	
	<xsl:template
		name="summary">
		<xsl:param
			name="results"/>
		<xsl:variable
			name="startTime"
			select="translate(TestSuite/@startTime,'T',' ')"/>
		<xsl:variable
			name="endTime">
			<xsl:choose>
				<xsl:when test="TestSuite/@endTime">
					<xsl:value-of select="translate(TestSuite/@endTime,'T',' ')"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="'Running...'"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable
			name="testsInSuite"
			select="count($results)"/>
		<xsl:variable
			name="testsPassed"
			select="count($results[@overallStatus='Passed'])"/>
		<xsl:variable
			name="testsFailed"
			select="count($results[@overallStatus='Failed'])"/>
		<table
			class="faux">
			<tr>
				<xsl:call-template
					name="X_writeNameValuePair">
					<xsl:with-param
						name="name"
						select="'Start Time'"/>
					<xsl:with-param
						name="value"
						select="$startTime"/>
				</xsl:call-template>
				<td
					class="spacer"/>
				<xsl:call-template
					name="X_writeNameValuePair">
					<xsl:with-param
						name="name"
						select="'Tests Passed'"/>
					<xsl:with-param
						name="value"
						select="concat(string( $testsPassed ) ,'(',if ($testsInSuite &gt; 0) then substring( string( ( $testsPassed div $testsInSuite ) * 100 ) ,1,6) else 0,'%)')"/>
				</xsl:call-template>
			</tr>
			<tr>
				<xsl:call-template
					name="X_writeNameValuePair">
					<xsl:with-param
						name="name"
						select="'End Time'"/>
					<xsl:with-param
						name="value"
						select="$endTime"/>
				</xsl:call-template>
				<td
					class="spacer"/>
				<xsl:call-template
					name="X_writeNameValuePair">
					<xsl:with-param
						name="name"
						select="'Tests Failed'"/>
					<xsl:with-param
						name="value"
						select="concat(string($testsFailed ) ,'(',if ($testsInSuite &gt; 0) then substring( string( ( $testsFailed div $testsInSuite ) * 100 ) ,1,6) else 0,'%)')"/>
				</xsl:call-template>
			</tr>
		</table>
	</xsl:template>
	
	<xsl:template
		name="table">
		<xsl:param
			name="results"/>
		<h2>Summary</h2>
		<table>
			<tr>
				<th>Resource</th>
				<th>Result</th>
				<th>Start Time</th>
				<th>End Time</th>
				<th>Run Time (ms)</th>
				<th>Errors</th>
				<th>Warnings</th>
			</tr>
			<xsl:for-each
				select="TestSuite/task">
				<xsl:variable
					name="taskName">
					<xsl:value-of
						select="@name"/>
				</xsl:variable>
				<xsl:variable
					name="logLocation">
					<xsl:value-of
						select="@logLocation"/>
				</xsl:variable>
				<xsl:for-each
					select="document(@logLocation)/Test">
					<tr>
						<td>
							<xsl:value-of
								select="$taskName"/>
						</td>
						<td>
							<xsl:attribute name="class">
								<xsl:value-of
									select="lower-case(summary/@overallStatus)"/>
							</xsl:attribute>
							<xsl:value-of
								select="summary/@overallStatus"/>
						</td>
						<xsl:call-template
							name="reportTestStartTime">
							<xsl:with-param
								name="useTitle"
								select="0"/>
						</xsl:call-template>
						<xsl:call-template
							name="reportTestEndTime">
							<xsl:with-param
								name="useTitle"
								select="0"/>
						</xsl:call-template>
						<td
							class="figure">
							<xsl:call-template
								name="getTestExecutionTime"/>
						</td>
						<td
							class="figure">
							<xsl:call-template
								name="getErrorMessages"/>
						</td>
						<td
							class="figure">
							<xsl:call-template
								name="getWarningMessages"/>
						</td>
					</tr>
				</xsl:for-each>
			</xsl:for-each>
		</table>
	</xsl:template>
	
	<xsl:template name="status">
		<xsl:param name="results"/>
		<xsl:choose>
			<xsl:when test="not(TestSuite/@endTime)">
				<xsl:value-of select="'Running'"/>
			</xsl:when>
			<xsl:when test="count($results) = count($results[@overallStatus='Passed']) and count($results)!= 0">
				<xsl:value-of select="'Passed'"/>
			</xsl:when>
			<xsl:when test="$results[@overallStatus='Cancelled']">
				<xsl:value-of select="'Cancelled'"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="'Failed'"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
