<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

	<xsl:template match="file_compare" mode="summary">
		<xsl:call-template name="processSummaryRow" />
	</xsl:template>

	<xsl:template match="file_compare" mode="label">
		<xsl:value-of select="'File Compare'" />
	</xsl:template>

	<xsl:template match="file_compare">
		<xsl:call-template name="addActionInfo" />
		<table class="faux">
			<xsl:call-template name="reportCommonInfo" />
			<xsl:call-template name="reportValidationError" />
			<xsl:call-template name="reportDiffCount" />
		</table>
		<xsl:call-template name="reportFileSources" />
		<xsl:call-template name="reportKeyFields" />
		<xsl:call-template name="reportComparisons" />
		<xsl:call-template name="reportMissingFileSource1Fields" />
		<xsl:call-template name="reportMissingFileSource2Fields" />
		<xsl:call-template name="reportConflicts" />
	</xsl:template>

	<xsl:template name="reportDiffCount">
		<xsl:if test="@diffCount">
			<xsl:call-template name="reportInfo">
				<xsl:with-param name="value" select="@diffCount" />
				<xsl:with-param name="name" select="'Total Differences'" />
			</xsl:call-template>
		</xsl:if>
	</xsl:template>

	<xsl:template name="reportFileSources">
		<xsl:if test="fileSource1">
			<table class="faux">
				<tr>
					<td>File Source 1</td>
					<td>
						<xsl:value-of select="fileSource1/@resourcePath" />
					</td>
				</tr>
				<tr>
					<td>File Source 2</td>
					<td>
						<xsl:value-of select="fileSource2/@resourcePath" />
					</td>
				</tr>
			</table>
		</xsl:if>
	</xsl:template>

	<xsl:template name="reportKeyFields">
		<xsl:variable name="keyFieldsCount" select="count(keyFields/field)" />
		<xsl:if test="$keyFieldsCount gt 0">
			<table class="dirTable">
				<tr>
					<th colspan="2">Record Mappings</th>
				</tr>
				<tr>
					<th>
						<xsl:value-of select="fileSource1/@resourcePath" />
					</th>
					<th>
						<xsl:value-of select="fileSource2/@resourcePath" />
					</th>
				</tr>
				<xsl:for-each select="keyFields/field">
					<tr>
						<td>
							<xsl:value-of select="@fileSource1" />
						</td>
						<td>
							<xsl:value-of select="@fileSource2" />
						</td>
					</tr>
				</xsl:for-each>
			</table>
		</xsl:if>
	</xsl:template>

	<xsl:template name="reportComparisons">
		<xsl:variable name="compCount" select="count(comparisons/comparison)" />
		<xsl:if test="$compCount gt 0">
			<table class="dirTable">
				<tr>
					<th colspan="4">Comparisons</th>
				</tr>
				<tr>
					<th>
						<xsl:value-of select="fileSource1/@resourceName" />
					</th>
					<th>Comparison Type</th>
					<th>
						<xsl:value-of select="fileSource2/@resourceName" />
					</th>
					<th>Tolerance</th>
				</tr>
				<xsl:for-each select="comparisons/comparison">
					<tr>
						<td>
							<xsl:value-of select="@fileSource1ColumnName" />
						</td>
						<td>
							<xsl:choose>
								<xsl:when test="@compareType='EQUALITY'">
									<xsl:value-of select="'Equals'" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="'Sum of'" />
								</xsl:otherwise>
							</xsl:choose>
						</td>
						<td>
							<xsl:value-of select="@fileSource2ColumnName" />
						</td>
						<td>
							<xsl:choose>
								<xsl:when test="@threshold">
									<xsl:value-of select="@threshold" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="'N/A'" />
								</xsl:otherwise>
							</xsl:choose>
						</td>
					</tr>
				</xsl:for-each>
			</table>
		</xsl:if>
	</xsl:template>

	<xsl:template name="reportMissingFileSource2Fields">
		<xsl:variable name="missingRowCount"
			select="count(missingRows/missingRow[@source=ancestor::file_compare/fileSource2/@resourcePath])" />
		<xsl:if test="$missingRowCount gt 0">
			<table class="dirTable">
				<tr>
					<th>
						<xsl:attribute name="colSpan"><xsl:value-of
							select="count(keyFields/field)" /></xsl:attribute>
						<xsl:value-of
							select="concat( $missingRowCount,' rows in ',fileSource2/@resourceName, ' missing from ',fileSource1/@resourceName)" />
					</th>
				</tr>
				<!--write out fields as headers -->
				<tr>
					<xsl:for-each select="keyFields/field">
						<th>
							<xsl:value-of select="@fileSource2" />
						</th>
					</xsl:for-each>
				</tr>
				<xsl:for-each
					select="missingRows/missingRow[@source=ancestor::file_compare/fileSource2/@resourcePath]">
					<tr>
						<xsl:for-each select="missingField">
							<!-- sort using the key fields order to ensure that we place each 
								value into the correct column -->
							<xsl:sort
								select="count(ancestor::file_compare/keyFields/field[@fileSource2=current()/@fieldName]/preceding-sibling::*)" />
							<td>
								<xsl:value-of select="@value" />
							</td>
						</xsl:for-each>
					</tr>
				</xsl:for-each>
			</table>
		</xsl:if>
	</xsl:template>

	<xsl:template name="reportMissingFileSource1Fields">
		<xsl:variable name="missingRowCount"
			select="count(missingRows/missingRow[@source=ancestor::file_compare/fileSource1/@resourcePath])" />
		<xsl:if test="$missingRowCount gt 0">
			<table class="dirTable">
				<tr>
					<th>
						<xsl:attribute name="colSpan"><xsl:value-of
							select="count(keyFields/field)" /></xsl:attribute>
						<xsl:value-of
							select="concat( $missingRowCount,' rows in ',fileSource1/@resourceName, ' missing from ',fileSource2/@resourceName)" />
					</th>
				</tr>
				<!--write out fields as headers -->
				<tr>
					<xsl:for-each select="keyFields/field">
						<th>
							<xsl:value-of select="@fileSource1" />
						</th>
					</xsl:for-each>
				</tr>
				<xsl:for-each
					select="missingRows/missingRow[@source=ancestor::file_compare/fileSource1/@resourcePath]">
					<tr>
						<xsl:for-each select="missingField">
							<!-- sort using the key fields order to ensure that we place each 
								value into the correct column -->
							<xsl:sort
								select="count(ancestor::file_compare/keyFields/field[@fileSource1=current()/@fieldName]/preceding-sibling::*)" />
							<td>
								<xsl:value-of select="@value" />
							</td>
						</xsl:for-each>
					</tr>
				</xsl:for-each>
			</table>
		</xsl:if>
	</xsl:template>

	<xsl:template name="reportConflicts">
		<xsl:variable name="conflictCount"
			select="count(failedComparisons/conflictingRow)" />
		<xsl:variable name="keyFieldsCount" select="count(keyFields/field)" />
		<xsl:variable name="comparisonCount" select="count(comparisons/comparison)" />

		<xsl:if test="$conflictCount gt 0">
			<table class="dirTable">
				<tr>
					<th colSpan="2" rowSpan="2">Files</th>
					<th>
						<xsl:attribute name="colSpan"><xsl:value-of
							select="$keyFieldsCount" /></xsl:attribute>
						<xsl:value-of select="'Key Columns'" />
					</th>
					<th>
						<xsl:attribute name="colSpan"><xsl:value-of
							select="$comparisonCount" /></xsl:attribute>
						<xsl:value-of select="'Comparison Columns'" />
					</th>
				</tr>
				<!--write out fields as headers -->
				<tr>
					<xsl:for-each select="keyFields/field">
						<th>
							<xsl:value-of select="@fileSource1" />
						</th>
					</xsl:for-each>
					<xsl:for-each select="comparisons/comparison">
						<th>
							<xsl:value-of
								select="concat(@fileSource1ColumnName,' = ', @fileSource2ColumnName)" />
						</th>
					</xsl:for-each>
				</tr>

				<xsl:for-each select="failedComparisons/conflictingRow">
					<tr>
						<td>
							<xsl:call-template name="getLastToken">
								<xsl:with-param name="text" select="@leftHandFile" />
								<xsl:with-param name="pattern" select="'[\\/]'" />
							</xsl:call-template>
						</td>
						<td>
							<xsl:call-template name="getLastToken">
								<xsl:with-param name="text" select="@rightHandFile" />
								<xsl:with-param name="pattern" select="'[\\/]'" />
							</xsl:call-template>
						</td>
						<xsl:apply-templates select="child::keyColumn" />
						<xsl:apply-templates select="child::compareColumn" />
					</tr>
				</xsl:for-each>
			</table>
		</xsl:if>
	</xsl:template>

	<xsl:template match="keyColumn">
		<td>
			<xsl:value-of select="@value" />
		</td>
	</xsl:template>

	<!-- Writes out the a cell showing a compared column values that were different -->
	<xsl:template match="compareColumn[@lhsValue != @rhsValue]">
		<td class="difference">
			<xsl:value-of select="concat(@lhsValue, ' &lt;&gt; ', @rhsValue)" />
		</td>
	</xsl:template>

	<!-- Writes out the a cell showing a compared column values that were the 
		same -->
	<xsl:template match="compareColumn[@lhsValue = @rhsValue]">
		<td>
			<xsl:value-of select="concat(@lhsValue, ' = ', @rhsValue)" />
		</td>
	</xsl:template>

	<xsl:template name="getLastToken">
		<xsl:param name="text" />
		<xsl:param name="pattern" />
		<xsl:variable name="tokens" select="tokenize($text,$pattern)" />
		<xsl:value-of select="$tokens[count($tokens)] " />
	</xsl:template>

</xsl:stylesheet>