<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet
    version="2.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:variable
        name="integration">integration</xsl:variable>
    <xsl:variable
        name="TD_SOURCE">tdSource</xsl:variable>
    <xsl:variable
        name="TD_SOURCE_OUTPUT">Source</xsl:variable>
        
    <xsl:variable
        name="QTP_REPORT">resultPath</xsl:variable>
    <xsl:variable
        name="QTP_REPORT_OUTPUT">Report Path</xsl:variable>

    <xsl:variable name="TD_ACTION_MESSAGE">actionMessage</xsl:variable>
    <xsl:variable name="TD_ACTION_MESSAGE_OUTPUT">Script Variables</xsl:variable>
    
    <xsl:variable name="TD_COLUMNS_TEXT_NAME">columns</xsl:variable>
    <xsl:variable name="TD_COLUMN_TEXT_NAME">column</xsl:variable>
    <xsl:variable name="TD_COLUMN_NAME_TEXT_NAME">columnName</xsl:variable>
    
    <xsl:variable name="TD_ROWS_TEXT_NAME">rows</xsl:variable>
    <xsl:variable name="TD_ROW_TEXT_NAME">row</xsl:variable>
    <xsl:variable name="TD_DATA_TEXT_NAME">data</xsl:variable>
    <xsl:variable name="TD_VALUE_TEXT_NAME">value</xsl:variable>
    
    <xsl:template
        match="guiinteraction"
        mode="summary">
        <xsl:call-template
            name="processSummaryRow"/>
    </xsl:template>
    
    <xsl:template
        match="guiinteraction"
        mode="label">
        <xsl:value-of
            select="'GUI Interaction'"/>
    </xsl:template>
    
    <xsl:template
        match="guiinteraction">
        <xsl:call-template
            name="addActionInfo"/>
        <table
            class="faux">
            <xsl:call-template
                name="reportSource"/>
            <xsl:if test="@integration='QTPIntegration'">
                <xsl:call-template
                    name="reportResultsPath"/>
            </xsl:if>
            <xsl:call-template
                name="reportCommonInfo"/>
            <xsl:call-template
                name="tdReportActionMessages"/>
        </table>
        <xsl:call-template
            name="tdReportResults"/>
    </xsl:template>
    
    <xsl:template
        name="reportSource">
        <xsl:call-template
            name="copyAttribute">
            <xsl:with-param
                name="attribute"
                select="$TD_SOURCE"/>
            <xsl:with-param
                name="outputAttribute"
                select="$TD_SOURCE_OUTPUT"/>
            <xsl:with-param
                name="formatNewLines"
                select="'false'"/>
        </xsl:call-template>
    </xsl:template>
    
    <xsl:template
        name="reportResultsPath">
        <xsl:call-template
            name="copyAttribute">
            <xsl:with-param
                name="attribute"
                select="$QTP_REPORT"/>
            <xsl:with-param
                name="outputAttribute"
                select="$QTP_REPORT_OUTPUT"/>
            <xsl:with-param
                name="formatNewLines"
                select="'false'"/>
        </xsl:call-template>
    </xsl:template>
    
    <xsl:template name="tdReportActionMessages">
        <xsl:if test="count(@*[name()=$ERROR])!=0">
            <tr>
                <xsl:call-template name="reportInfo">
                    <xsl:with-param name="name" select="$ERROR_OUTPUT" />
                    <xsl:with-param name="value" select="@*[name()=$ERROR]" />
                    <xsl:with-param name="tdSpan" select="4" />
                </xsl:call-template>
            </tr>
        </xsl:if>
        <xsl:if test="count(*[name()=$TD_ACTION_MESSAGE and not(@containsDataSet)])!=0">
            <xsl:for-each select="*[name()=$TD_ACTION_MESSAGE and not(@containsDataSet)]">
                <tr>
                    <xsl:call-template name="reportInfo">
                        <xsl:with-param name="name" select="$TD_ACTION_MESSAGE_OUTPUT" />
                        <xsl:with-param name="value" select="text()" />
                        <xsl:with-param name="tdSpan" select="4" />
                    </xsl:call-template>
                </tr>
            </xsl:for-each>
        </xsl:if>
    </xsl:template>
    
    <xsl:template name="tdReportResults">
        <xsl:if test="count(*[name()=$TD_ACTION_MESSAGE and @containsDataSet])!=0">
            <div style="margin: 0px 0px 10px 0px;">
                Script Data Set Variables<br/>
                <table>
                    <xsl:for-each select="*[name()=$TD_ACTION_MESSAGE and @containsDataSet]">
                        <xsl:call-template name="tdHandleColumns" />
                        <xsl:call-template name="tdHandleRows" />
                    </xsl:for-each>
                </table>
            </div>
        </xsl:if>
    </xsl:template>
    
    <xsl:template name="tdHandleColumns">
        <tr>
            <xsl:for-each select="*[name()=$TD_COLUMNS_TEXT_NAME]">
                <xsl:for-each select="*[name()=$TD_COLUMN_TEXT_NAME]">
                    <xsl:for-each select="*[name()=$TD_COLUMN_NAME_TEXT_NAME]">
                        <th>
                            <xsl:value-of select="text()" />
                        </th>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:for-each>
        </tr>
    </xsl:template>
    
    <xsl:template name="tdHandleRows">
        <xsl:for-each select="*[name()=$TD_ROWS_TEXT_NAME]">
            <xsl:for-each select="*[name()=$TD_ROW_TEXT_NAME]">        
                <tr>
                    <xsl:for-each select="*[name()=$TD_DATA_TEXT_NAME]">
                        <xsl:for-each select="*[name()=$TD_VALUE_TEXT_NAME]">
                            <td>
                                <xsl:value-of select="text()" />
                            </td>
                        </xsl:for-each>
                    </xsl:for-each>
                </tr>
            </xsl:for-each>
        </xsl:for-each>     
    </xsl:template>
    
</xsl:stylesheet>
