<?xml version="1.0"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

    <!--GLOBAL ATTRIBUTES USED BY ALL OTHER IPROCESS TEMPLATES-->
    <xsl:variable name="notApplicable"></xsl:variable>

    <!--This template constructs the general report-->
    <xsl:template name="IProcessActionGeneralReport">

        <!-- VARIABLES -->
        <xsl:variable name="nodeName" select="./iprocessNodeName"/>
        <xsl:variable name="sessionId" select="./iprocessSessionID"/>
        <xsl:variable name="identity" select="./iprocessIdentity"/>
        <xsl:variable name="identityType" select="./iprocessIdentityType"/>
        <xsl:variable name="identityGroup" select="./iprocessIdentityGroup"/>
        <xsl:variable name="retryInterval" select="./iprocessRetryInterval"/>
        <xsl:variable name="retryTimeout" select="./iprocessRetryTimeOut"/>
        <xsl:variable name="errorCode" select="./iprocessErrorCode"/>
        <xsl:variable name="errorGroup" select="./iprocessErrorGroup"/>
        <xsl:variable name="warning" select="./iprocessWarning"/>

        <div class="iprocess">
            <!-- ////// IPROCESS ACTION GENERAL REPORT //////-->
            <table width="100%">
                <tr class="iprocessGeneralHeader">
                    <th rowspan="2">Resource</th>
                    <th colspan="2">Errors</th>
                    <th rowspan="2">Warnings</th>
                    <th rowspan="2">Node ID</th>
                    <th rowspan="2">Session ID</th>
                    <th colspan="2">Identity</th>
                    <th colspan="2">Retry Parameters</th>
                </tr>

                <tr class="iprocessGeneralHeader">
                    <!--Resource header-->
                    <td>Error Group</td>
                    <td>Error Code</td>
                    <!--Warnings header-->
                    <!--Node ID header-->
                    <!--Session ID header-->
                    <td>User name</td>
                    <td>Group name</td>
                    <td>Interval(ms)</td>
                    <td>Timeout(ms)</td>
                </tr>
                <!-- END HEADING -->
                <!-- ////////// NOW RENDER THE DETAILS ///////////-->
                <tr class="iprocessGeneralData">
                    <td>
                        <xsl:apply-templates select="." mode="label"/>
                    </td>
                    <td>
                        <xsl:value-of select="$errorGroup"/>
                    </td>
                    <td>
                        <xsl:value-of select="$errorCode"/>
                    </td>
                    <td>
                        <xsl:value-of select="$warning"/>
                    </td>
                    <td>
                        <xsl:value-of select="$nodeName"/>
                    </td>
                    <td>
                        <xsl:value-of select="$sessionId"/>
                    </td>
                    <td>
                        <xsl:value-of select="$identity"/>
                    </td>
                    <td>
                        <xsl:value-of select="$identityGroup"/>
                    </td>
                    <td>
                        <xsl:value-of select="$retryInterval"/>
                    </td>
                    <td>
                        <xsl:value-of select="$retryTimeout"/>
                    </td>
                </tr>
            </table>
        </div>
    </xsl:template>


    <!--
        This teplate renders the configuration report for all the actions.
        This templaces houses the values from the configuration panel of every
        action excluding the message editor.
    -->
    <xsl:template name="IProcessActionConfigurationReport">

        <!--UNION OF VARIABLES THOSE ARE USED IN CONFIGURATION PANEL OF ALL THE ACTIONS-->
        <xsl:variable name="procedure" select="./iprocessProcedure"/>
        <xsl:variable name="initialStep" select="./iprocessInitialStep"/>
        <xsl:variable name="step" select="./iprocessStep"/>
        <xsl:variable name="eventStep" select="./iprocessEventStep"/>
        <xsl:variable name="shortDescription" select="./iprocessInitialStepShortDescription"/>
        <xsl:variable name="closeCaseCaseNumber" select="./iprocessCloseCaseCaseNumber"/>
        <xsl:variable name="serverSideCaseFilterExpressions" select="./iprocessServerSideCaseFilterExpressions"/>
        <xsl:variable name="serverSideWorkItemFilterExpressions" select="./iprocessServerSideWorkItemFilterExpressions"/>
        <xsl:variable name="workQueue" select="./iprocessWorkQueue"/>
        <xsl:variable name="retainLock" select="./iprocessRetainLock"/>
        <xsl:variable name="linkedAction" select="./iprocessLinkedAction"/>
        <xsl:variable name="changeOption" select="./iprocessprocessworkitemchangeoption"/>


        <div class="iprocess">
            <table width="100%">
                <tr class="iprocessGeneralHeader">
                    <th colspan="2">Configuration</th>
                </tr>

                <!--CONFIGURATION FIELDS GIVEN BELOW-->
                <!--procedure-->
                <xsl:if test="string-length(string($procedure)) != 0">
                    <tr class="iprocessGeneralData">
                        <td>Procedure</td>
                        <td>
                            <xsl:value-of select="$procedure"/>
                        </td>
                    </tr>
                </xsl:if>

                <!--initial step only in the case of start case-->
                <xsl:if test="string-length(string($initialStep)) != 0">
                    <tr class="iprocessGeneralData">
                        <td>Initial Step</td>
                        <td>
                            <xsl:value-of select="$initialStep"/>
                        </td>
                    </tr>
                </xsl:if>

                <!--ordinary step - for example in the case of retrieve task-->
                <xsl:if test="string-length(string($step)) != 0">
                    <tr class="iprocessGeneralData">
                        <td>Step</td>
                        <td>
                            <xsl:value-of select="$step"/>
                        </td>
                    </tr>
                </xsl:if>

                <!--Event step in the case of trigger event-->
                <xsl:if test="string-length(string($eventStep)) != 0">
                    <tr class="iprocessGeneralData">
                        <td>Event Step</td>
                        <td>
                            <xsl:value-of select="$eventStep"/>
                        </td>
                    </tr>
                </xsl:if>

                <!--short description associated with every step-->
                <xsl:if test="string-length(string($shortDescription)) != 0">
                    <tr class="iprocessGeneralData">
                        <td>Short Description</td>
                        <td>
                            <xsl:value-of select="$shortDescription"/>
                        </td>
                    </tr>
                </xsl:if>

                <!--work queue-->
                <xsl:if test="string-length(string($workQueue)) != 0">
                    <tr class="iprocessGeneralData">
                        <td>Work Queue</td>
                        <td>
                            <xsl:value-of select="$workQueue"/>
                        </td>
                    </tr>
                </xsl:if>

                <!--case number  - in the case of close case action-->
                <xsl:if test="string-length(string($closeCaseCaseNumber)) != 0">
                    <tr class="iprocessGeneralData">
                        <td>Case Number</td>
                        <td>
                            <xsl:value-of select="$closeCaseCaseNumber"/>
                        </td>
                    </tr>
                </xsl:if>

                <!--server side case filter expressions -->
                <xsl:if test="string-length(string($serverSideCaseFilterExpressions)) != 0">
                    <tr class="iprocessGeneralData">
                        <td>Case Filter Expression</td>
                        <td>
                            <xsl:value-of select="$serverSideCaseFilterExpressions"/>
                        </td>
                    </tr>
                </xsl:if>

                <!--retain lock-->
                <xsl:if test="string-length(string($retainLock)) != 0">
                    <tr class="iprocessGeneralData">
                        <td>Retain Lock</td>
                        <td>
                            <xsl:value-of select="$retainLock"/>
                        </td>
                    </tr>
                </xsl:if>
                <!--server side task filter expressions -->
                <xsl:if test="string-length(string($serverSideWorkItemFilterExpressions)) != 0">
                    <tr class="iprocessGeneralData">
                        <td>Task Filter Expression</td>
                        <td>
                            <xsl:value-of select="$serverSideWorkItemFilterExpressions"/>
                        </td>
                    </tr>
                </xsl:if>
                <!--linkedAction -->
                <xsl:if test="string-length(string($linkedAction)) != 0">
                    <tr class="iprocessGeneralData">
                        <td>Linked Action</td>
                        <td>
                            <xsl:value-of select="$linkedAction"/>
                        </td>
                    </tr>
                </xsl:if>
                <!--server side task filter expressions -->
                <xsl:if test="string-length(string($changeOption)) != 0">
                    <tr class="iprocessGeneralData">
                        <td>Change Option</td>
                        <td>
                            <xsl:value-of select="$changeOption"/>
                        </td>
                    </tr>
                </xsl:if>
            </table>
        </div>
    </xsl:template>



    <!--
    This template renders polling information

    following params are required for task 

    @param caption - this will be set to the table

    following params are required for task
    
    @param col1 - header value for col1
    @param col2 - header value for col2
    @param col3 - header value for col3
    @param col4 - header value for col4
    @param col5 - header value for col5

    -->
    <xsl:template name="IProcessActionsPollingReportForWorkItemRetrieval">

        <!--col params-->
        <xsl:param name="col1"/>
        <xsl:param name="col2"/>
        <xsl:param name="col3"/>
        <xsl:param name="col4"/>
        <xsl:param name="col5"/>


        <div class="iprocess">
            <table width="100%">
                <!--render column titles-->
                <tr class="iprocessGeneralHeader">
                    <th><xsl:value-of select="$col1"/></th>
                    <th><xsl:value-of select="$col2"/></th>
                    <th><xsl:value-of select="$col3"/></th>
                    <th><xsl:value-of select="$col4"/></th>
                    <th><xsl:value-of select="$col5"/></th>
                </tr>
                
                <!--render polling data-->
                <xsl:for-each select="pollingLog">
                   <xsl:variable name="timestamp" select="substring-after(./@iprocesspollingtime,'T')"/>
                   <xsl:variable name="isRefresh" select="./@isRefresh"/>
                   <xsl:variable name="workItemListChanged" select="./@workItemListChanged"/>
                   <xsl:variable name="workItemStateChanged" select="./@workItemStateChanged"/>
                   <xsl:variable name="numberOfWorkItemsDetected" select="./@numberOfWorkItemsDetected"/>
                   
                   <tr class="iprocessGeneralData">
                       <td><xsl:value-of select="$timestamp"/></td>
                       <td><xsl:value-of select="$numberOfWorkItemsDetected"/></td>
                       <td><xsl:value-of select="$isRefresh"/></td>>
                       <td><xsl:value-of select="$workItemListChanged"/></td>
                       <td><xsl:value-of select="$workItemStateChanged"/></td>
                   </tr>

                </xsl:for-each>
            </table>
        </div>
    </xsl:template>



    <!--
    This template renders the polling data when we have tried to 
    retrieve cases

    following params are required for case 

    @param caption - this will be set to the table

    following params are required for case
    
    @param col1 - header value for col1
    @param col2 - header value for col2
    @param col3 - header value for col3
    @param col4 - header value for col4
    -->
    <xsl:template name="IProcessActionsPollingReportForCaseRetrieval">
        <!--col params-->
        <xsl:param name="col1"/>
        <xsl:param name="col2"/>
        <xsl:param name="col3"/>
        <xsl:param name="col4"/>

        <div class="iprocess">
            <table width="100%">
                <!--render column titles-->
                <tr class="iprocessGeneralHeader">
                    <th><xsl:value-of select="$col1"/></th>
                    <th><xsl:value-of select="$col2"/></th>
                    <th><xsl:value-of select="$col3"/></th>
                    <th><xsl:value-of select="$col4"/></th>
                </tr>
                
                <!--render polling data-->
                <xsl:for-each select="pollingLog">

                   <xsl:variable name="timestamp" select="substring-after(./@iprocesspollingtime,'T')"/>
                   <xsl:variable name="caseListChanged" select="./@caseListChanged"/>
                   <xsl:variable name="caseStateChanged" select="./@caseStateChanged"/>
                   <xsl:variable name="numberOfCasesDetected" select="./@numberOfCasesDetected"/>
                   
                   <tr class="iprocessGeneralData">
                       <td><xsl:value-of select="$timestamp"/></td>
                       <td><xsl:value-of select="$numberOfCasesDetected"/></td>
                       <td><xsl:value-of select="$caseListChanged"/></td>
                       <td><xsl:value-of select="$caseStateChanged"/></td>
                   </tr>
                        
                </xsl:for-each>
            </table>
        </div>
    </xsl:template>
</xsl:stylesheet>
