<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet
	version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:x="http://www.greenhatsoftware.com/functions/Detailed%20Report.xsl">
	<xsl:variable
		name="ITERATION">iteration</xsl:variable>
	<xsl:variable
		name="ITERATION_OUTPUT">Iteration</xsl:variable>
	<xsl:variable
		name="ITERATION_NUMBER">iterationNumber</xsl:variable>
	<xsl:variable
		name="ITERATION_NUMBER_OUTPUT">Iteration Number</xsl:variable>
	<xsl:variable
		name="ITERATION_COUNT">iterationCount</xsl:variable>

	<xsl:template
		match="iteration"
		mode="summary">
		<xsl:call-template
			name="processSummaryRow">
			<xsl:with-param
				name="name"
				select="concat('Iteration#',string-join(ancestor-or-self::iteration/@iterationNumber,'.'))"/>
			<xsl:with-param
				name="label"
				select="false()"/>
		</xsl:call-template>
	</xsl:template>

	<xsl:template
		name="generateIterationName">
		<xsl:variable
			name="testID">
			<xsl:call-template
				name="getTestID"/>
		</xsl:variable>
		<xsl:choose>
			<xsl:when
				test="@id!=$testID">
				<xsl:variable
					name="id">
					<xsl:value-of
						select="@id"/>
				</xsl:variable>
				<xsl:choose>
					<xsl:when
						test="count(parent::*[name()=$SERIAL_TASK]) &gt; 0">
						<xsl:value-of
							select="parent::*/@id"/>
						<xsl:value-of
							select="string(':')"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:for-each
							select="/descendant-or-self::*[@childTaskId=$id][1]">
							<xsl:value-of
								select="@id"/>
							<xsl:value-of
								select="string(':')"/>
						</xsl:for-each>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
		</xsl:choose>
		<xsl:value-of
			select="concat($ITERATION_OUTPUT,'#',string-join(ancestor-or-self::iteration/@iterationNumber,'.'))"/>
	</xsl:template>

	<xsl:template
		name="getIterationID">
		<xsl:value-of
			select="string-join(ancestor-or-self::iteration/@iterationNumber,'.')"/>
	</xsl:template>

	<xsl:template
		name="getIterationCount">
		<xsl:param
			name="id"/>
		<xsl:variable
			name="testId">
			<xsl:choose>
				<xsl:when
					test="string-length($id)!=0">
					<xsl:value-of
						select="$id"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template
						name="getTestID"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:for-each
			select="/Test/summary[@id=$testId]">
			<xsl:value-of
				select="x:notBlank(@*[name()=$ITERATION_COUNT])"/>
		</xsl:for-each>
	</xsl:template>

	<xsl:template
		match="iteration">
		<xsl:variable
			name="name">
			<xsl:variable
				name="id">
				<xsl:call-template
					name="generateIterationName"/>
			</xsl:variable>
			<xsl:choose>
				<xsl:when
					test="$id=string('Iteration#Multiple Instance')">
					<xsl:variable
						name="instCount"
						select="/*/runProfileProperties/@performanceInstances"/>
					<xsl:value-of
						select="$instCount"/>
					<xsl:choose>
						<xsl:when
							test="number($instCount)=1">
							<xsl:value-of
								select="string(' instance of ')"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of
								select="string(' instances of ')"/>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:call-template
						name="getTestID"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of
						select="$id"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:call-template
			name="addSectionHeader">
			<xsl:with-param
				name="header"
				select="$name"/>
		</xsl:call-template>
		<xsl:call-template
			name="createSummaryTable"/>
		<xsl:call-template
			name="processTagDataStore">
			<xsl:with-param
				name="elementName"
				select="$TAG_VALUES"/>
			<xsl:with-param
				name="tableName"
				select="$TAG_VALUES_OUTPUT"/>
		</xsl:call-template>
		<xsl:apply-templates
			select="*"/>
	</xsl:template>

	<xsl:template
		name="reportIterationNumber">
		<xsl:param
			name="withTitle"
			select="true()"/>
		<xsl:call-template
			name="copyAttribute">
			<xsl:with-param
				name="attribute"
				select="$ITERATION_NUMBER"/>
			<xsl:with-param
				name="outputAttribute"
				select="$ITERATION_NUMBER_OUTPUT"/>
			<xsl:with-param
				name="withTitle"
				select="$withTitle"/>
		</xsl:call-template>
	</xsl:template>

	<xsl:template
		name="processTestDataSet">
		<xsl:if
			test="//runProfileProperties[ string-length( @testDataTestDataSetPath ) &gt;0 ]">
			<xsl:call-template
				name="addSectionHeader">
				<xsl:with-param
					name="header">Test Data Set</xsl:with-param>
			</xsl:call-template>
			<table>
				<tr>
					<th>Name:</th>
					<td>
						<xsl:value-of
							select="//runProfileProperties/@testDataTestDataSetPath"/>
					</td>
				</tr>
			</table>
			<xsl:call-template
				name="addSectionHeader">
				<xsl:with-param
					name="header">Usage Summary</xsl:with-param>
			</xsl:call-template>
			<table>
				<th>Data Row</th>
				<th>Iteration</th>
				<xsl:call-template
					name="processTestData"/>
			</table>
		</xsl:if>
	</xsl:template>

	<xsl:template
		name="processTestData">
		<xsl:param
			name="count"
			select="number(0)"/>
		<xsl:variable
			name="usedRow">
			<xsl:if
				test="count(//iteration[((number(@iterationNumber) -1) mod number(//runProfileProperties/@testDataSetRows))=$count ])!=0">
				<xsl:value-of
					select="'used'"/>
			</xsl:if>
		</xsl:variable>
		<xsl:if
			test="$usedRow='used' and number($count) &lt; number(//runProfileProperties/@testDataSetRows)">
			<tr>
				<td>
					<xsl:value-of
						select="number($count)+1"/>
				</td>
				<td>
					<xsl:for-each
						select="//iteration[((number(@iterationNumber) -1) mod number(//runProfileProperties/@testDataSetRows))=$count ]">
						<xsl:variable
							name="displayName"
							select="concat(string('Iteration#'),string(@iterationNumber) )"/>
						<a>
							<xsl:attribute
								name="href">
								<xsl:value-of
									select="concat('#',generate-id())"/>
							</xsl:attribute>
							<xsl:value-of
								select="$displayName"/>
						</a>
						<xsl:variable
							name="counter"
							select="count(preceding-sibling::*[name()='iteration' and ( ( (number(@iterationNumber)-1) mod number(//runProfileProperties/@testDataSetRows) )=$count)])"/>
						<xsl:variable
							name="total"
							select=" count(//iteration[((number(@iterationNumber) -1) mod number(//runProfileProperties/@testDataSetRows))=$count ])"/>
						<xsl:if
							test="number($counter)+1 &lt; number($total)">
							<xsl:value-of
								select="string('--')"/>
						</xsl:if>
					</xsl:for-each>
				</td>
			</tr>
			<xsl:call-template
				name="processTestData">
				<xsl:with-param
					name="count"
					select="number($count)+1"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>